==> dnet-openaire-exporter-1.1.19-20210209.103045-74-sources.jar: eu/dnetlib/openaire/context/ContextApiCore.java <==
package eu.dnetlib.openaire.context;

import java.io.IOException;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.google.common.base.Splitter;
import eu.dnetlib.openaire.common.ISClient;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Component;

@Component
@ConditionalOnProperty(value = "openaire.exporter.enable.context", havingValue = "true")
public class ContextApiCore {

	private static final Log log = LogFactory.getLog(ContextApiCore.class);
	private static final String SEPARATOR = "::";

	@Autowired
	private ISClient isClient;

	public List<ContextSummary> listContexts() throws ContextException {
		return getContextMap().values().stream()
				.map(c -> new ContextSummary()
						.setId(c.getId())
						.setType(c.getType())
						.setLabel(c.getLabel())
						.setStatus(c.getParams().containsKey("status") ? c.getParams().get("status").get(0).getValue() : ""))
				.collect(Collectors.toList());
	}

	public List<CategorySummary> listCategories(final String contextId) throws ContextException {
		return getContextMap().get(contextId).getCategories().values().stream()
				.filter(Category::isClaim)
				.map(c -> new CategorySummary()
						.setId(c.getId())
						.setLabel(c.getLabel())
						.setHasConcept(c.hasConcepts()))
				.collect(Collectors.toList());
	}

	public List<ConceptSummary> listConcepts(final String categoryId) throws ContextException {
		final String contextId = StringUtils.substringBefore(categoryId, SEPARATOR);
		return getContextMap().get(contextId).getCategories().get(categoryId).getConcepts().stream()
				.filter(Concept::isClaim)
				.map(c -> new ConceptSummary()
						.setId(c.getId())
						.setLabel(c.getLabel())
						.setHasSubConcept(c.hasSubConcepts()))
				.collect(Collectors.toList());

	}

	public List<ConceptSummary> listSubConcepts(final String conceptId) throws ContextException {
		final List<String> ids = Splitter.on(SEPARATOR).splitToList(conceptId);
		if (ids.size() < 3) {
			throw new ContextException("");
		}

		final String contextId = ids.get(0);
		final String categoryId = contextId + SEPARATOR + ids.get(1);

		final List<Concept> concepts = getContextMap().get(contextId).getCategories().get(categoryId).getConcepts()
				.stream()
				.filter(c -> conceptId.equals(c.getId()))
				.filter(Concept::isClaim)
				.collect(Collectors.toList());

		return mapConcepts(concepts);
	}

	private List<ConceptSummary> mapConcepts(final List<Concept> concepts) {
		if (concepts == null || concepts.isEmpty()) {
			return null;
		}
		return concepts.stream()
				.map(c -> new ConceptSummary()
						.setId(c.getId())
						.setLabel(c.getLabel())
						.setHasSubConcept(c.hasSubConcepts())
						.setConcept(mapConcepts(c.getConcepts())))
				.collect(Collectors.toList());
	}

	private Map<String, Context> getContextMap() throws ContextException {
		try {
			return isClient.getContextMap();
		} catch (IOException e) {
			throw new ContextException(e);
		}
	}


}

==> dnet-openaire-exporter-1.1.21-20210312.094431-15-sources.jar: eu/dnetlib/openaire/context/ContextApiCore.java <==
package eu.dnetlib.openaire.context;

import java.io.IOException;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import com.google.common.base.Splitter;
import eu.dnetlib.openaire.common.ISClient;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Component;

@Component
@ConditionalOnProperty(value = "openaire.exporter.enable.context", havingValue = "true")
public class ContextApiCore {

	private static final Log log = LogFactory.getLog(ContextApiCore.class);
	private static final String SEPARATOR = "::";

	@Autowired
	private ISClient isClient;

	public List<ContextSummary> listContexts() throws ContextException {
		return getContextMap().values().stream()
				.map(c -> new ContextSummary()
						.setId(c.getId())
						.setType(c.getType())
						.setLabel(c.getLabel())
						.setStatus(c.getParams().containsKey("status") ? c.getParams().get("status").get(0).getValue() : ""))
				.collect(Collectors.toList());
	}

	public List<CategorySummary> listCategories(final String contextId, Boolean all) throws ContextException {
		final Stream<Category> categories = getContextMap().get(contextId).getCategories().values().stream();
		return all ? asCategorySummaries(categories) : asCategorySummaries(categories.filter(Category::isClaim));
	}

	private List<CategorySummary> asCategorySummaries(Stream<Category> categories) {
		return categories
				.map(c -> new CategorySummary()
						.setId(c.getId())
						.setLabel(c.getLabel())
						.setHasConcept(c.hasConcepts()))
				.collect(Collectors.toList());
	}

	public List<ConceptSummary> listConcepts(final String categoryId, Boolean all) throws ContextException {
		final String contextId = StringUtils.substringBefore(categoryId, SEPARATOR);
		final Stream<Concept> concepts = getContextMap().get(contextId)
				.getCategories()
				.get(categoryId)
				.getConcepts()
				.stream();

		return all ? asConceptSummaries(concepts) : asConceptSummaries(concepts.filter(Concept::isClaim));
	}

	private List<ConceptSummary> asConceptSummaries(Stream<Concept> concepts) {
		return concepts
				.map(c -> new ConceptSummary()
						.setId(c.getId())
						.setLabel(c.getLabel())
						.setHasSubConcept(c.hasSubConcepts()))
				.collect(Collectors.toList());
	}

	public List<ConceptSummary> listSubConcepts(final String conceptId, Boolean all) throws ContextException {
		final List<String> ids = Splitter.on(SEPARATOR).splitToList(conceptId);
		if (ids.size() < 3) {
			throw new ContextException("");
		}

		final String contextId = ids.get(0);
		final String categoryId = contextId + SEPARATOR + ids.get(1);

		final Stream<Concept> concepts = getContextMap().get(contextId)
				.getCategories()
				.get(categoryId)
				.getConcepts()
				.stream()
				.filter(c -> conceptId.equals(c.getId()));

		return all ?
				mapConcepts(concepts.filter(Concept::isClaim).collect(Collectors.toList())) :
				mapConcepts(concepts.collect(Collectors.toList()));
	}

	private List<ConceptSummary> mapConcepts(final List<Concept> concepts) {
		if (concepts == null || concepts.isEmpty()) {
			return null;
		}
		return concepts.stream()
				.map(c -> new ConceptSummary()
						.setId(c.getId())
						.setLabel(c.getLabel())
						.setHasSubConcept(c.hasSubConcepts())
						.setConcept(mapConcepts(c.getConcepts())))
				.collect(Collectors.toList());
	}

	private Map<String, Context> getContextMap() throws ContextException {
		try {
			return isClient.getContextMap();
		} catch (IOException e) {
			throw new ContextException(e);
		}
	}


}
